# azuma

[![PyPI version](https://badge.fury.io/py/azuma.svg)](https://badge.fury.io/py/azuma)
[![Test](https://github.com/ninoseki/azuma/actions/workflows/test.yml/badge.svg)](https://github.com/ninoseki/azuma/actions/workflows/test.yml)

Yet another [Sigma](https://github.com/SigmaHQ/sigma) library for Python.

Note: This is a forked version of [CybercentreCanada/pysigma](https://github.com/CybercentreCanada/pysigma). Most of the things in this library come from their hard work.

See [documentation](https://ninoseki.github.io/azuma/) for more details.

## Alternatives

- https://github.com/bradleyjkemp/sigma-go
- https://github.com/markuskont/go-sigma-rule-engine
- https://github.com/binalyze/tigma
